@@ -76,9 +76,7 @@ Qt6CTPlatformTheme::Qt6CTPlatformTheme()
 }
 
 Qt6CTPlatformTheme::~Qt6CTPlatformTheme()
-{
-    delete m_palette;
-}
+{}
 
 bool Qt6CTPlatformTheme::usePlatformNativeDialog(DialogType type) const
 {
@@ -94,8 +92,7 @@ QPlatformDialogHelper *Qt6CTPlatformTheme::createPlatformDialogHelper(DialogType
 
 const QPalette *Qt6CTPlatformTheme::palette(QPlatformTheme::Palette type) const
 {
-    Q_UNUSED(type);
-    return (m_usePalette && m_palette) ? m_palette : nullptr;
+    return (m_usePalette && m_palette) ? m_palette.get() : QGenericUnixTheme::palette(type);
 }
 
 const QFont *Qt6CTPlatformTheme::font(QPlatformTheme::Font type) const
@@ -184,7 +181,7 @@ void Qt6CTPlatformTheme::applySettings()
         }
 
         if(!m_palette)
-            m_palette = new QPalette(qApp->style()->standardPalette());
+            m_palette = std::make_unique<QPalette>(*QGenericUnixTheme::palette(QPlatformTheme::SystemPalette));
 
         if(m_update && m_usePalette)
             qApp->setPalette(*m_palette);
@@ -251,11 +248,7 @@ void Qt6CTPlatformTheme::updateSettings()
 
 void Qt6CTPlatformTheme::readSettings()
 {
-    if(m_palette)
-    {
-        delete m_palette;
-        m_palette = nullptr;
-    }
+    m_palette.reset();
 
     QSettings settings(Qt6CT::configFile(), QSettings::IniFormat);
 
@@ -265,7 +258,7 @@ void Qt6CTPlatformTheme::readSettings()
     if(!schemePath.isEmpty() && settings.value("custom_palette", false).toBool())
     {
         schemePath = Qt6CT::resolvePath(schemePath); //replace environment variables
-        m_palette = new QPalette(loadColorScheme(schemePath));
+        m_palette = std::make_unique<QPalette>(Qt6CT::loadColorScheme(schemePath, *QPlatformTheme::palette(SystemPalette)));
     }
     m_iconTheme = settings.value("icon_theme").toString();
     //load dialogs
@@ -273,18 +266,12 @@ void Qt6CTPlatformTheme::readSettings()
     {
         //do not mix gtk2 style and gtk3 dialogs
         QStringList keys = QPlatformThemeFactory::keys();
-        QString name = settings.value("standard_dialogs", "default").toString();
-        if((m_style == QLatin1String("gtk2") || m_style == QLatin1String("qt5gtk2")) &&
-                (name == QLatin1String("gtk3") || name == QLatin1String("qt5gtk3")))
-        {
-            name = QLatin1String("gtk2");
-        }
-        if(keys.contains(name))
-            m_theme.reset(QPlatformThemeFactory::create(name));
-        else if(name == QLatin1String("gtk2") && keys.contains("qt5gtk2"))
-            m_theme.reset(QPlatformThemeFactory::create("qt5gtk2"));
-        else if(name == QLatin1String("gtk3") && keys.contains("qt5gtk3"))
-            m_theme.reset(QPlatformThemeFactory::create("qt5gtk3"));
+        QString dialogs = settings.value("standard_dialogs", "default").toString();
+
+        if(m_style.endsWith("gtk2") && dialogs == QLatin1String("gtk3"))
+            dialogs = QLatin1String("gtk2");
+        if(keys.contains(dialogs))
+            m_theme.reset(QPlatformThemeFactory::create(dialogs));
     }
 
     settings.endGroup();
@@ -365,7 +352,7 @@ bool Qt6CTPlatformTheme::hasWidgets()
 QString Qt6CTPlatformTheme::loadStyleSheets(const QStringList &paths)
 {
     QString content;
-    for(const QString &path : paths)
+    for(const QString &path : qAsConst(paths))
     {
         if(!QFile::exists(path))
             continue;
@@ -380,33 +367,3 @@ QString Qt6CTPlatformTheme::loadStyleSheets(const QStringList &paths)
     content.replace(regExp, "\n");
     return content;
 }
-
-QPalette Qt6CTPlatformTheme::loadColorScheme(const QString &filePath)
-{
-    QPalette customPalette;
-    QSettings settings(filePath, QSettings::IniFormat);
-    settings.beginGroup("ColorScheme");
-    QStringList activeColors = settings.value("active_colors").toStringList();
-    QStringList inactiveColors = settings.value("inactive_colors").toStringList();
-    QStringList disabledColors = settings.value("disabled_colors").toStringList();
-    settings.endGroup();
-
-    if(activeColors.count() == QPalette::NColorRoles &&
-            inactiveColors.count() == QPalette::NColorRoles &&
-            disabledColors.count() == QPalette::NColorRoles)
-    {
-        for (int i = 0; i < QPalette::NColorRoles; i++)
-        {
-            QPalette::ColorRole role = QPalette::ColorRole(i);
-            customPalette.setColor(QPalette::Active, role, QColor(activeColors.at(i)));
-            customPalette.setColor(QPalette::Inactive, role, QColor(inactiveColors.at(i)));
-            customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
-        }
-    }
-    else
-    {
-        customPalette = *QPlatformTheme::palette(SystemPalette); //load fallback palette
-    }
-
-    return customPalette;
-}
