@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2020-2023, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -30,18 +30,21 @@
 #define QT6CTPROXYSTYLE_H
 
 #include <QProxyStyle>
+#include "qt6ct.h"
 
-class Qt6CTProxyStyle : public QProxyStyle
+class Qt6CTProxyStyle : public QProxyStyle, public Qt6CT::StyleInstance
 {
     Q_OBJECT
 public:
-    explicit Qt6CTProxyStyle(const QString &key);
+    explicit Qt6CTProxyStyle();
+    void reloadSettings() override;
 
     virtual ~Qt6CTProxyStyle();
 
     int styleHint(StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returnData) const override;
 
 private:
+    QString m_style;
     int m_dialogButtonsHaveIcons;
     int m_activateItemOnSingleClick;
     int m_underlineShortcut;
