@@ -49,6 +49,7 @@ AppearancePage::AppearancePage(QWidget *parent) :
     m_ui->setupUi(this);
     QStringList keys = QStyleFactory::keys();
     keys.removeAll("qt6ct-style"); //hide qt6ct proxy style
+    keys.removeAll("qt5ct-style"); //hide qt5ct proxy style
     keys.removeAll("qt5gtk2"); //hide qt5gtk2 alias
     keys.removeAll("gtk2"); //hide gtk2 alias
     m_ui->styleComboBox->addItems(keys);
@@ -101,15 +102,14 @@ AppearancePage::~AppearancePage()
     delete m_previewUi;
 }
 
-void AppearancePage::writeSettings()
+void AppearancePage::writeSettings(QSettings *settings)
 {
-    QSettings settings(Qt6CT::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Appearance");
-    settings.setValue("style", m_ui->styleComboBox->currentText());
-    settings.setValue("custom_palette", m_ui->customPaletteButton->isChecked());
-    settings.setValue("color_scheme_path", m_ui->colorSchemeComboBox->currentData().toString());
-    settings.setValue("standard_dialogs", m_ui->dialogComboBox->currentData().toString());
-    settings.endGroup();
+    settings->beginGroup("Appearance");
+    settings->setValue("style", m_ui->styleComboBox->currentText());
+    settings->setValue("custom_palette", m_ui->customPaletteButton->isChecked());
+    settings->setValue("color_scheme_path", m_ui->colorSchemeComboBox->currentData().toString());
+    settings->setValue("standard_dialogs", m_ui->dialogComboBox->currentData().toString());
+    settings->endGroup();
 }
 
 void AppearancePage::on_styleComboBox_textActivated(const QString &text)
@@ -127,7 +127,7 @@ void AppearancePage::on_styleComboBox_textActivated(const QString &text)
 
 void AppearancePage::on_colorSchemeComboBox_activated(int)
 {
-    m_customPalette = loadColorScheme(m_ui->colorSchemeComboBox->currentData().toString());
+    m_customPalette = Qt6CT::loadColorScheme(m_ui->colorSchemeComboBox->currentData().toString(), palette());
     updatePalette();
 }
 
@@ -342,7 +342,7 @@ void AppearancePage::readSettings()
         int index = m_ui->colorSchemeComboBox->findData(colorSchemePath);
         if(index >= 0)
             m_ui->colorSchemeComboBox->setCurrentIndex(index);
-        m_customPalette = loadColorScheme(m_ui->colorSchemeComboBox->currentData().toString());
+        m_customPalette = Qt6CT::loadColorScheme(m_ui->colorSchemeComboBox->currentData().toString(), palette());
     }
 
     on_styleComboBox_textActivated(m_ui->styleComboBox->currentText());
@@ -395,36 +395,6 @@ void AppearancePage::findColorSchemes(const QStringList &paths)
         findColorSchemes(p);
 }
 
-QPalette AppearancePage::loadColorScheme(const QString &filePath)
-{
-    QPalette customPalette;
-    QSettings settings(filePath, QSettings::IniFormat);
-    settings.beginGroup("ColorScheme");
-    QStringList activeColors = settings.value("active_colors").toStringList();
-    QStringList inactiveColors = settings.value("inactive_colors").toStringList();
-    QStringList disabledColors = settings.value("disabled_colors").toStringList();
-    settings.endGroup();
-
-    if(activeColors.count() == QPalette::NColorRoles &&
-            inactiveColors.count() == QPalette::NColorRoles &&
-            disabledColors.count() == QPalette::NColorRoles)
-    {
-        for (int i = 0; i < QPalette::NColorRoles; i++)
-        {
-            QPalette::ColorRole role = QPalette::ColorRole(i);
-            customPalette.setColor(QPalette::Active, role, QColor(activeColors.at(i)));
-            customPalette.setColor(QPalette::Inactive, role, QColor(inactiveColors.at(i)));
-            customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
-        }
-    }
-    else
-    {
-        customPalette = palette(); //load fallback palette
-    }
-
-    return customPalette;
-}
-
 void AppearancePage::createColorScheme(const QString &name, const QPalette &palette)
 {
     QSettings settings(name, QSettings::IniFormat);
