@@ -43,8 +43,8 @@ FontsPage::FontsPage(QWidget *parent) :
 {
     m_ui->setupUi(this);
 
-    connect(m_ui->changeGeneralFontButton, &QToolButton::clicked, [=] { onFontChangeRequested(m_ui->generalFontLabel); } );
-    connect(m_ui->changeFixedWidthFontButton, &QToolButton::clicked, [=] { onFontChangeRequested(m_ui->fixedFontLabel); } );
+    connect(m_ui->changeGeneralFontButton, &QToolButton::clicked, this, [=] { onFontChangeRequested(m_ui->generalFontLabel); } );
+    connect(m_ui->changeFixedWidthFontButton, &QToolButton::clicked, this, [=] { onFontChangeRequested(m_ui->fixedFontLabel); } );
 
     readSettings();
 
@@ -58,13 +58,12 @@ FontsPage::~FontsPage()
     delete m_ui;
 }
 
-void FontsPage::writeSettings()
+void FontsPage::writeSettings(QSettings *settings)
 {
-    QSettings settings(Qt6CT::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Fonts");
-    settings.setValue("general", m_ui->generalFontLabel->font().toString());
-    settings.setValue("fixed", m_ui->fixedFontLabel->font().toString());
-    settings.endGroup();
+    settings->beginGroup("Fonts");
+    settings->setValue("general", m_ui->generalFontLabel->font().toString());
+    settings->setValue("fixed", m_ui->fixedFontLabel->font().toString());
+    settings->endGroup();
 }
 
 void FontsPage::onFontChangeRequested(QWidget *widget)
